Clinical Genomics Report - 643594

#### Leveransrapport Clinical Genomics

- Leveransrapport för KTH, familj 643594
  Datum: 2018-06-21

#### Kontakt Clinical Genomics

#### Kundinformation

Prov | Familj | Kön | Status | Vävnad | Ticket | Analys
--- | --- | --- | --- | --- | --- | ---
ADM1059A2 | 643594 | male ( analys: male ) | affected | N/A | 643594 | WGSPCFC030
ADM1059A1 | 643594 | female ( analys: female ) | unaffected | N/A | 643594 | WGSPCFC030
ADM1059A3 | 643594 | female ( analys: female ) | unaffected | N/A | 643594 | WGSPCFC030

Prov | Ankomstdatum | Biblioteksberedning | Sekvensering | Analys | Svarsdatum
--- | --- | --- | --- | --- | ---
ADM1059A2 | N/A | N/A | 2016-04-15 | N/A | N/A
ADM1059A1 | N/A | N/A | 2016-04-15 | N/A | N/A
ADM1059A3 | N/A | N/A | 2016-04-15 | N/A | N/A

Familj | MIP-version | Genpaneler | Genomversion
643594 | v4.0.3 | panel1 | GRCh37

Resultat baserade på prob-regioner för riktade analyser såsom "EXO*" och "EFT*".
Prov | Läspar [M] | Mappade sekvenser [%] | Medelsekvensdjup | Täckningsgrad 10x [%] | Duplikat [%]
--- | --- | --- | --- | --- | ---
ADM1059A2 | 104.4 | 99.91 | 289.1 | 94.05 | 9.8
ADM1059A1 | 94.6 | 99.9 | 160.0 | 94.04 | 9.8
ADM1059A3 | 111.2 | 99.9 | 190.0 | 94.17 | 10.5

Varianter finns uppladdade i Scout: http://localhost:5000/cust000/643594

#### Teknisk beskrivning av analysen: WGSPCFC030

Whole genome sequencing, 30X coverage. TruSeq PCR free prep.

#### Signatur för godkännande av rapport

Virta Waltteri
Head of unit, Clinical Genomics